.. _dipy_developers:

Developers
==========


The core development team consists of the following individuals:

- **Eleftherios Garyfallidis**, University of Cambridge, UK 
- **Ian Nimmo-Smith**, MRC Cognition and Brain Sciences Unit, Cambridge, UK
- **Matthew Brett**, University of California, Berkeley, CA, US
- **Bago Amirbekian**, University of California, San Francisco, CA, US
- **Ariel Rokem**, Stanford University, CA, US
- **Stefan Van der Walt**, Stellenbosch University, ZA

The following people have also contributed to the project:

- **Maxime Descoteaux**, University of Sherbrooke, QC, CA
- **Michael Pacquette**, University of Sherbrooke, QC, CA
- **Christopher Nguyen**, University of California, Los Angeles, CA, US
- **Emanuele Olivetti**, NeuroInformatics Laboratory (NILab), Trento, IT
- **Yaroslav Halchenco**, PBS Department, Dartmouth, NH, US
- **Samuel St. Jean**, University of Sherbrooke, QC, CA


Collaboration is the heart of Dipy_ philosophy. We encourage everyone from anywhere in the world who wants to be involved in the project to contact us.

.. include:: links_names.inc
